@@ -1,12 +1,12 @@
 <?php
 /**
- * Copyright 2008-2015 Horde LLC (http://www.horde.org/)
+ * Copyright 2008-2016 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
  *
  * @category  Horde
- * @copyright 2008-2015 Horde LLC
+ * @copyright 2008-2016 Horde LLC
  * @license   http://www.horde.org/licenses/lgpl21 LGPL 2.1
  * @package   Imap_Client
  */
@@ -19,7 +19,7 @@
  *
  * @author    Michael Slusarz <slusarz@horde.org>
  * @category  Horde
- * @copyright 2008-2015 Horde LLC
+ * @copyright 2008-2016 Horde LLC
  * @license   http://www.horde.org/licenses/lgpl21 LGPL 2.1
  * @package   Imap_Client
  */
@@ -260,7 +260,9 @@ class Horde_Imap_Client_Exception extends Horde_Exception_Wrapped
         parent::__construct($message, $code);
 
         $this->raw_msg = $this->message;
-        $this->message = Horde_Imap_Client_Translation::t($this->message);
+        try {
+            $this->message = Horde_Imap_Client_Translation::t($this->message);
+        } catch (Horde_Translation_Exception $e) {}
     }
 
     /**
